from distutils.core import setup

setup(
    name='chopoff',
    version='1.0',
    packages=['', 'chopoff'],
    url='https://github.com/danidee10/chopoff',
    license='MIT License',
    author='danidee',
    author_email='osaetindaniel@gmail.com',
    description='A small python library that returns the remainder of an iterable slice in python'
)
